@@ -58,8 +58,7 @@ class HealSparseMap(object):
         if cov_index_map is not None and cov_map is not None:
             raise RuntimeError('Cannot specify both cov_index_map and cov_map')
         if cov_index_map is not None:
-            import warnings
-            warnings.warn("cov_index_map deprecated", DeprecationWarning)
+            warnings.warn("cov_index_map deprecated", DeprecationWarning, stacklevel=2)
             cov_map = HealSparseCoverage(cov_index_map, nside_sparse)
 
         if cov_map is not None and sparse_map is not None and nside_sparse is not None:
@@ -534,9 +533,10 @@ class HealSparseMap(object):
             raise ValueError("Values are not a numpy ndarray")
 
         if hasattr(pixels, "__len__") and len(pixels) == 0:
-            if not is_single_value:
-                raise ValueError("Shape mismatch: cannot set an array of values "
-                                 "to a zero-length list of pixels.")
+            if len(_values) != 0:
+                warnings.warn("Shape mismatch: using a non-zero-length array of values "
+                              "to set a zero-length list of pixels.",
+                              UserWarning)
             # Nothing to do
             return
 
@@ -741,7 +741,10 @@ class HealSparseMap(object):
             Array of values/validity from the map.
         """
         if hasattr(pixels, "__len__") and len(pixels) == 0:
-            return np.array([], dtype=self.dtype)
+            if self._is_wide_mask:
+                return np.zeros((0, self._wide_mask_width), dtype=self.dtype)
+            else:
+                return np.array([], dtype=self.dtype)
 
         if not nest:
             _pix = hpg.ring_to_nest(self._nside_sparse, pixels)
@@ -1532,6 +1535,70 @@ class HealSparseMap(object):
 
         return new_map
 
+    def interpolate_pos(self, ra_or_theta, dec_or_phi, lonlat=True, allow_partial=False):
+        """
+        Return the bilinear interpolation of the map using 4 nearest neighbors.
+
+        Parameters
+        ----------
+        ra_or_theta : `float`, array-like
+            Angular coordinates of points on a sphere.
+        dec_or_phi : `float`, array-like
+            Angular coordinates of points on a sphere.
+        lonlat : `bool`, optional
+            If True, input angles are longitude and latitude in degrees.
+            Otherwise, they are co-latitude and longitude in radians.
+        allow_partial : `bool`, optional
+            If this is True, then unseen (not validvalid) neighbors will be
+            ignored and the output value will be the weighted average of the
+            valid neighbors. Otherwise, if any neighbor is not valid then
+            the interpolated value will be set to UNSEEN.
+
+        Returns
+        -------
+        values : `np.ndarray`
+            Array of interpolated values corresponding to input positions.
+            The return array will always be 64-bit floats.
+
+        Notes
+        -----
+        The interpolation routing works only on numeric data, and not on wide
+        mask maps, recarray maps, or boolean maps.
+        """
+        if self._is_wide_mask:
+            raise NotImplementedError("Interpolation does not run on a wide mask map.")
+        elif self._is_rec_array:
+            raise NotImplementedError("Interpolation does not run on a recarray map.")
+        elif isinstance(self._sentinel, bool):
+            raise NotImplementedError("Interpolation does not run on a boolean map.")
+
+        interp_pix, interp_wgt = hpg.get_interpolation_weights(
+            self.nside_sparse,
+            np.atleast_1d(ra_or_theta),
+            np.atleast_1d(dec_or_phi),
+            lonlat=lonlat,
+        )
+        aux = self.get_values_pix(interp_pix)
+        out_of_bounds = (aux == self._sentinel)
+        aux = aux.astype(np.float64)
+        aux[out_of_bounds] = np.nan
+
+        if not allow_partial:
+            # Any pixel that has an out-of-bounds neighbor will be set to UNSEEN.
+            values = np.nansum(aux * interp_wgt, axis=1) / np.sum(interp_wgt, axis=1)
+            values[~np.all(~out_of_bounds, axis=1)] = hpg.UNSEEN
+        else:
+            # Use only the neighbor pixels that are valid.
+            interp_wgt[out_of_bounds] = np.nan
+            wgt_sum = np.nansum(interp_wgt, axis=1)
+            values = np.nansum(aux * interp_wgt, axis=1)
+            all_bad = (wgt_sum == 0.0)
+            values[~all_bad] /= wgt_sum[~all_bad]
+            # Any pixel that has all bad neighbors will be UNSEEN.
+            values[all_bad] = hpg.UNSEEN
+
+        return values
+
     def __getitem__(self, key):
         """
         Get part of a healpix map.
@@ -1559,10 +1626,9 @@ class HealSparseMap(object):
         elif isinstance(key, list):
             # Make sure that it's integers
             arr = np.atleast_1d(key)
-            if len(arr) == 0:
-                return np.array([], dtype=self.dtype)
-            if not is_integer_value(arr[0]):
-                raise IndexError("List array indices must be integers for __getitem__")
+            if len(arr) > 0:
+                if not is_integer_value(arr[0]):
+                    raise IndexError("List array indices must be integers for __getitem__")
             return self.get_values_pix(arr)
         else:
             raise IndexError("Illegal index type (%s) for __getitem__ in HealSparseMap." %
@@ -1723,11 +1789,12 @@ class HealSparseMap(object):
         elif self._is_wide_mask:
             raise RuntimeError("Cannot convert datatype of a wide mask.")
 
-        new_sparse_map = self._sparse_map.astype(dtype)
-        _sentinel = check_sentinel(new_sparse_map.dtype.type, sentinel)
+        new_sparse_map = np.zeros(self._sparse_map.shape, dtype=dtype)
+        valid_pix = (self._sparse_map != self._sentinel)
+        new_sparse_map[valid_pix] = self._sparse_map[valid_pix].astype(dtype)
 
-        invalid_pix = (self._sparse_map == self._sentinel)
-        new_sparse_map[invalid_pix] = _sentinel
+        _sentinel = check_sentinel(new_sparse_map.dtype.type, sentinel)
+        new_sparse_map[~valid_pix] = _sentinel
 
         return HealSparseMap(cov_map=self._cov_map, sparse_map=new_sparse_map,
                              nside_sparse=self.nside_sparse, sentinel=_sentinel)
