@@ -1,9 +1,7 @@
-from __future__ import division, absolute_import, print_function
-
 import unittest
 import numpy.testing as testing
 import numpy as np
-import healpy as hp
+import hpgeom as hpg
 import healsparse
 
 
@@ -17,7 +15,7 @@ class CoverageMaskTestCase(unittest.TestCase):
         # Number of non-masked pixels in the coverage map resolution
         non_masked_px = 10
         nfine = (nside_map//nside_coverage)**2
-        full_map = np.zeros(hp.nside2npix(nside_map)) + hp.UNSEEN
+        full_map = np.zeros(hpg.nside_to_npixel(nside_map)) + hpg.UNSEEN
         full_map[0: non_masked_px*nfine] = 1 + np.random.random(size=non_masked_px*nfine)
 
         # Generate sparse map
@@ -26,7 +24,7 @@ class CoverageMaskTestCase(unittest.TestCase):
 
         # Build the "original" coverage mask
 
-        cov_mask_orig = np.zeros(hp.nside2npix(nside_coverage), dtype=np.bool_)
+        cov_mask_orig = np.zeros(hpg.nside_to_npixel(nside_coverage), dtype=np.bool_)
         idx_cov = np.unique(np.right_shift(np.arange(0, non_masked_px*nfine), sparse_map._cov_map.bit_shift))
         cov_mask_orig[idx_cov] = 1
 
